@@ -53,6 +53,7 @@ main (int argc, char *argv[])
 {
 	GtkWidget *window;
 	GtkWidget *menu_quit, *menu_about, *menu_copy, *menu_clear_history;
+	GtkWidget *menu_beep;
 	GladeXML *xml;
 	GtkWidget *notebook;
 	const gchar *dialog = DATADIR "gnome-nettool.glade";
@@ -64,7 +65,6 @@ main (int argc, char *argv[])
 	Netinfo *lookup;
 	Netinfo *finger;
 	Netinfo *whois;
-	GtkIconInfo *icon_info;
 	gint current_page = 0;
 	static gchar *info_input = NULL;
 	static gchar *ping_input = NULL;
@@ -130,12 +130,8 @@ main (int argc, char *argv[])
 		return -1;
 	}
 
-	icon_info = gtk_icon_theme_lookup_icon (gtk_icon_theme_get_default (), "gnome-nettool", 48, 0);
-	if (icon_info != NULL) {
-		gtk_window_set_default_icon_from_file (gtk_icon_info_get_filename (icon_info), NULL);
-		gtk_icon_info_free (icon_info);
-	}
-
+	gtk_window_set_default_icon_name ("gnome-nettool");
+	
 	xml = glade_xml_new (dialog, "main_window", NULL);
 	window = glade_xml_get_widget (xml, "main_window");
 
@@ -220,6 +216,12 @@ main (int argc, char *argv[])
 	g_signal_connect (G_OBJECT (menu_quit), "activate",
 			  G_CALLBACK (gn_quit_app),
 			  NULL);
+
+	menu_beep = glade_xml_get_widget (xml, "m_beep");
+
+	g_signal_connect (G_OBJECT (menu_beep), "activate",
+			  G_CALLBACK (on_beep_activate),
+			  (gpointer) pinger); 
 	
 	menu_about = glade_xml_get_widget (xml, "m_about");
 
@@ -921,7 +923,7 @@ load_finger_widgets_from_xml (GladeXML * xml)
 	tips = gtk_tooltips_new ();
 	gtk_tooltips_set_tip (tips, GTK_WIDGET (entry_host),
 			      _("Enter the network address to finger that user.\n"
-				"For example: www.domain.com or 192.168.2.1"),
+			        "For example: auth.domain.com or 192.168.2.1"),
 			      NULL);
 
 	completion = gtk_entry_completion_new ();
